@@ -94,7 +94,9 @@ explicit_guide.yamlet <- function(
 #' Default mapping function for \code{\link{explicit_guide.yamlet}}
 #' where it replaces the key 'guide' with the return value.
 #'
-#' * If x is a list or has length greater than 1, result is 'codelist'.
+#' * If x is a list, the result is 'codelist'.
+#'
+#' * If x otherwise has length greater than 1, result is the default value.
 #'
 #' * If x \code{\link{is_parseable}}, result is 'units'.
 #'   Use \code{\link[units]{install_unit}} to register a non-default unit.
@@ -124,7 +126,7 @@ explicit_guide.yamlet <- function(
 #' infer_guide('z') # unrecognized as unit, evaluates to guide
 #' \dontrun{
 #' # evaluates to codelist but data suggests otherwise (warning)
-#' infer_guide(letters, data = LETTERS)
+#' infer_guide(as.list(letters), data = LETTERS)
 #' }
 #' infer_guide(c(1,2,3))                   # guide
 #' infer_guide(list('a','b','c'))          # codelist
@@ -142,7 +144,7 @@ infer_guide <- function(
   token = 'data',
   ...
 ){
-  stopifnot(is.atomic(data))
+  stopifnot(is.atomic(data)||is.null(data))
   stopifnot(length(token) == 1)
   token <- as.character(token)
   res <- case_when(
